@@ -12,7 +12,7 @@ from .check_rule import (
     is_bot_enabled,
     is_group_admin,
     is_group_admin_if_is_in_group,
-    should_respond_to_message,
+    should_respond_with_usage_check,
 )
 from .handlers.add_notices import add_notices
 from .handlers.chat import chat
@@ -24,6 +24,7 @@ from .handlers.enable import enable
 from .handlers.fakepeople_switch import switch
 from .handlers.insights import insights
 from .handlers.poke_event import poke_event
+from .handlers.preset_test import t_preset
 from .handlers.presets import presets
 from .handlers.prompt import prompt
 from .handlers.recall import recall
@@ -53,7 +54,7 @@ base_matcher.on_notice(
 base_matcher.on_message(
     block=False,
     priority=11,
-    rule=Rule(should_respond_to_message, is_bot_enabled),
+    rule=Rule(should_respond_with_usage_check, is_bot_enabled),
 ).append_handler(chat)
 
 # 添加各种命令处理器
@@ -148,7 +149,7 @@ base_matcher.on_command(
     aliases={"失忆", "删除记忆", "删除历史消息", "删除回忆"},
     block=True,
     priority=10,
-    permission=is_group_admin,
+    permission=is_group_admin_if_is_in_group,
     state=MatcherData(
         name="删除记忆",
         description="删除AI的历史记忆",
@@ -193,3 +194,15 @@ base_matcher.on_command(
         usage="/insights [global]",
     ).model_dump(),
 ).append_handler(insights)
+
+base_matcher.on_command(
+    "test_preset",
+    aliases={"测试预设"},
+    block=True,
+    priority=10,
+    state=MatcherData(
+        name="测试预设",
+        description="测试所有预设,--details查看详细结果",
+        usage="/test_preset [-d|--details]",
+    ).model_dump(),
+).append_handler(t_preset)
