@@ -1,11 +1,13 @@
 from dataclasses import dataclass
 from datetime import datetime
+from typing import Literal
 
 from nonebot import logger, require
 from sqlalchemy import delete, insert, select
 from sqlalchemy.exc import IntegrityError
 
 require("nonebot_plugin_orm")
+from async_lru import alru_cache
 from nonebot_plugin_orm import get_session
 
 from .models import GroupBlacklist, PrivateBlacklist
@@ -18,8 +20,41 @@ class BL_Data:
 
 
 class BL_Manager:
+    """
+    黑名单管理器
+    """
+
+    @staticmethod
+    def del_cache(
+        which: Literal["private", "group", "all"] = "all", where: str = "all"
+    ):
+        to_cache_private = (
+            BL_Manager.is_private_black,
+            BL_Manager.get_private_blacklist,
+        )
+        to_cache_group = (
+            BL_Manager.get_group_blacklist,
+            BL_Manager.is_group_black,
+        )
+        if which in ["all", "private"]:
+            for func in to_cache_private:
+                if which == "all" or where == "all":
+                    func.cache_clear()
+                else:
+                    func.cache_invalidate(where)
+
+        if which in ["all", "group"]:
+            for func in to_cache_group:
+                if which == "all" or where == "all":
+                    func.cache_clear()
+                else:
+                    func.cache_invalidate(where)
+
+        BL_Manager.get_full_blacklist.cache_clear()
+
     @staticmethod
     async def private_append(user_id: str, reason: str = "违反使用规则！"):
+        BL_Manager.del_cache("private", user_id)
         async with get_session() as session:
             stmt = insert(PrivateBlacklist).values(user_id=user_id, reason=reason)
             await session.execute(stmt)
@@ -28,6 +63,7 @@ class BL_Manager:
 
     @staticmethod
     async def group_append(group_id: str, reason: str = "违反使用规则！"):
+        BL_Manager.del_cache("group", group_id)
         async with get_session() as session:
             try:
                 stmt = insert(GroupBlacklist).values(group_id=group_id, reason=reason)
@@ -39,6 +75,7 @@ class BL_Manager:
 
     @staticmethod
     async def private_remove(user_id: str):
+        BL_Manager.del_cache("private", user_id)
         async with get_session() as session:
             stmt = delete(PrivateBlacklist).where(PrivateBlacklist.user_id == user_id)
             result = await session.execute(stmt)
@@ -51,6 +88,7 @@ class BL_Manager:
 
     @staticmethod
     async def group_remove(group_id: str):
+        BL_Manager.del_cache("group", group_id)
         async with get_session() as session:
             stmt = delete(GroupBlacklist).where(GroupBlacklist.group_id == group_id)
             result = await session.execute(stmt)
@@ -62,6 +100,7 @@ class BL_Manager:
                 logger.warning(f"群组{group_id}不在黑名单中")
 
     @staticmethod
+    @alru_cache(1024)
     async def is_private_black(user_id: str) -> bool:
         async with get_session() as session:
             stmt = (
@@ -73,6 +112,7 @@ class BL_Manager:
             return result.scalar_one_or_none() is not None
 
     @staticmethod
+    @alru_cache(1024)
     async def is_group_black(group_id: str) -> bool:
         async with get_session() as session:
             stmt = (
@@ -84,6 +124,7 @@ class BL_Manager:
             return result.scalar_one_or_none() is not None
 
     @staticmethod
+    @alru_cache(1024)
     async def get_private_blacklist() -> dict[str, str]:
         async with get_session() as session:
             stmt = select(PrivateBlacklist).with_for_update()
@@ -92,6 +133,7 @@ class BL_Manager:
             return {record.user_id: record.reason for record in records}
 
     @staticmethod
+    @alru_cache(1024)
     async def get_group_blacklist() -> dict[str, str]:
         async with get_session() as session:
             stmt = select(GroupBlacklist).with_for_update()
@@ -100,6 +142,7 @@ class BL_Manager:
             return {record.group_id: record.reason for record in records}
 
     @staticmethod
+    @alru_cache(1024)
     async def get_full_blacklist() -> dict[str, dict[str, BL_Data]]:
         async with get_session() as session:
             private_blacklist = (
